"use strict";
// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
Object.defineProperty(exports, "__esModule", { value: true });
var application_1 = require("@quantlab/application");
var apputils_1 = require("@quantlab/apputils");
var docregistry_1 = require("@quantlab/docregistry");
require("../style/index.css");
/**
 * The name of the factory that creates markdown widgets.
 */
var FACTORY = 'Markdown Preview';
/**
 * The command IDs used by the document manager plugin.
 */
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.preview = 'markdownviewer:open';
})(CommandIDs || (CommandIDs = {}));
/**
 * The markdown handler extension.
 */
var plugin = {
    activate: activate,
    id: 'jupyter.extensions.rendered-markdown',
    requires: [application_1.ILayoutRestorer],
    autoStart: true
};
/**
 * Activate the markdown plugin.
 */
function activate(app, restorer) {
    var primaryFileType = app.docRegistry.getFileType('markdown');
    var factory = new docregistry_1.MimeDocumentFactory({
        name: FACTORY,
        primaryFileType: primaryFileType,
        fileTypes: ['markdown'],
        defaultFor: ['markdown'],
        rendermime: app.rendermime
    });
    app.docRegistry.addWidgetFactory(factory);
    var commands = app.commands;
    var namespace = 'rendered-markdown';
    var tracker = new apputils_1.InstanceTracker({ namespace: namespace });
    // Handle state restoration.
    restorer.restore(tracker, {
        command: 'docmanager:open',
        args: function (widget) { return ({ path: widget.context.path, factory: FACTORY }); },
        name: function (widget) { return widget.context.path; }
    });
    factory.widgetCreated.connect(function (sender, widget) {
        // Notify the instance tracker if restore data needs to update.
        widget.context.pathChanged.connect(function () { tracker.save(widget); });
        tracker.add(widget);
    });
    commands.addCommand(CommandIDs.preview, {
        label: 'Markdown Preview',
        execute: function (args) {
            var path = args['path'];
            if (typeof path !== 'string') {
                return;
            }
            return commands.execute('docmanager:open', {
                path: path, factory: FACTORY
            });
        }
    });
}
/**
 * Export the plugin as default.
 */
exports.default = plugin;
//# sourceMappingURL=index.js.map